@@ -6,6 +6,7 @@ import shutil
 import subprocess
 from tempfile import NamedTemporaryFile
 
+import cv2
 import skvideo.io
 
 
@@ -80,3 +81,25 @@ def split_video(video_file_path, output_path=None,
         command.append(str(output_path))
         print(f'Running \"{" ".join(command)}\"')
         subprocess.call(command)
+
+
+def extract_target_frame_from_timestamp(video_filepath, timestamp):
+    """Extract target frame from timestamp.
+
+    Parameters
+    ----------
+    video_filepath : str
+        video filepath
+    timestamp : float
+        timestamp in seconds.
+
+    Returns
+    -------
+    image : numppy.ndarray
+    """
+    duration = get_video_duration(video_filepath)
+    timestamp = max(0.0, min(duration, timestamp))
+    vidcap = cv2.VideoCapture(str(video_filepath))
+    vidcap.set(cv2.CAP_PROP_POS_MSEC, int(timestamp * 1000))
+    success, image = vidcap.read()
+    return image
